==> org-lsst-ccs-config-1.0.2-sources.jar: org/lsst/ccs/config/DBInterface.java <==
package org.lsst.ccs.config;

import java.util.Collection;
import java.util.List;

/**
 * defines the basic methods implemented by a Data Access Object.
 * Note that many types are package protected so implementors whould be in the same package.
 * @author bamade
 */
// Date: 13/04/12

interface DBInterface {
    /**
     * starts a transaction
     */
    public void begin() ;

    /**
     * end a transaction
     */
    public void end() ;

    /**
     * failure: must close transaction
     */
    public void fail() ;

    /**
     * same as fail but a Throwable can be used to log.
     * @param th
     */
    public void fail(Throwable th) ;


    /**
     * saves the argument: which must now becomes immutable and be numbered (with an ID)
     * @param newDescription
     */
    public void saveSubsystemDescription (ASubsystemDescription newDescription) ;

    /**
     * saves the argument
     * @param ghosts
     */
    public void saveGhostDescriptions (GhostSubsystemDescription ghosts);

    /**
     *  gets a SubsystemDescription in the corresponding active object table.
     * @param name
     * @param tag
     * @return null if not found
     */
    public ASubsystemDescription getActiveSubsystemDescription(String name, String tag) ;

    /**
     * gets a subsystem descirption by it"s id
     * @param id
     * @return
     */
    public ASubsystemDescription getActiveSubsystemDescription(long id) ;

    /**
     * returns ghost with corresponding id
     * @param id
     * @return null if not found
     */
    public GhostSubsystemDescription getGhostDescription(long id) ;

    /**
     * deletes an active description
     * @param oldDescription
     */
    public void deleteActiveSubsystemDescription(ASubsystemDescription oldDescription) ;

    /**
     * saves the new argument: ID is modified and argument becomes immutable.
     * @param newProfile
     */
    public void saveConfigProfile(AConfigProfile newProfile) ;
    // marks the Ghost's end date

    /**
     * saves argument
     * @param deprecatedProfile
     */
    public void savePastProfile(PastConfigProfile deprecatedProfile) ;

    /**
     * get configProfile with name and tag
     * @param name
     * @param tag
     * @return null if not found
     */
    public AConfigProfile getActiveConfigProfile(String name, String tag) ;

    /**
     * delectes the active profile from DB
     * @param oldProfile
     */
    public void deleteActiveConfigProfile(AConfigProfile oldProfile) ;

    /**
     * registers a modified  parameter
     * @param config
     */
    public void modifyParmConfig(AParameterConfiguration config) ;

    /**
     * gets the active configProfiles that references an active SubsystemDescription
     * @param description
     * @return
     */
    public Collection<AConfigProfile> getActiveProfilesForSubsystem(ASubsystemDescription description) ;

    /**
     * get the deprecated ConfigProfile that referenced a subsystemDescription (active or deprecated)
     * @param description
     * @return
     */
    public Collection<PastConfigProfile> getProfilesForSubsystem(GhostSubsystemDescription description) ;

    /**
     * saves a run history
     * @param runHistory
     */
    public void saveRun(RunHistory runHistory) ;

    /**
     * saves a preparedConfiguration
     * @param preparedConfiguration
     */
    public void savePreparedConfiguration(PreparedConfiguration preparedConfiguration) ;

    /**
     * returns a prepared Configuration
     * @param subsystemName
     * @param configName
     * @param tag
     * @return null if not found
     */
    public PreparedConfiguration getPreparedConfiguration(String subsystemName, String configName, String tag) ;

    /**
     * saves a machine configuration
     * @param machineConfiguration
     */
    public void saveMachineConfiguration(MachineConfiguration machineConfiguration) ;

    /**
     * get a machine configuration..
     * @param macAddress
     * @return null if not found
     */
    public MachineConfiguration getMachineConfiguration(String macAddress) ;

    /**
     * execut simple request (read only: select of From)
     * @param hqlString
     * @return
     */
    public List<?> simpleHQLRequest(String hqlString) ;

    /**
     * claose all
     */
    public void close() ;
}

==> org-lsst-ccs-config-1.0.3-sources.jar: org/lsst/ccs/config/DBInterface.java <==
package org.lsst.ccs.config;

import java.util.Collection;
import java.util.List;

/**
 * defines the basic methods implemented by a Data Access Object.
 * Note that many types are package protected so implementors whould be in the same package.
 * @author bamade
 */
// Date: 13/04/12

public interface DBInterface {
    /**
     * starts a transaction
     */
    public void begin() ;

    /**
     * end a transaction
     */
    public void end() ;

    /**
     * failure: must close transaction
     */
    public void fail() ;

    /**
     * same as fail but a Throwable can be used to log.
     * @param th
     */
    public void fail(Throwable th) ;


    /**
     * saves the argument: which must now becomes immutable and be numbered (with an ID)
     * @param newDescription
     */
    public void saveSubsystemDescription (ASubsystemDescription newDescription) ;

    /**
     * saves the argument
     * @param ghosts
     */
    public void saveGhostDescriptions (GhostSubsystemDescription ghosts);

    /**
     *  gets a SubsystemDescription in the corresponding active object table.
     * @param name
     * @param tag
     * @return null if not found
     */
    public ASubsystemDescription getActiveSubsystemDescription(String name, String tag) ;

    /**
     * gets a subsystem descirption by it"s id
     * @param id
     * @return
     */
    public ASubsystemDescription getActiveSubsystemDescription(long id) ;

    /**
     * returns ghost with corresponding id
     * @param id
     * @return null if not found
     */
    public GhostSubsystemDescription getGhostDescription(long id) ;

    /**
     * deletes an active description
     * @param oldDescription
     */
    public void deleteActiveSubsystemDescription(ASubsystemDescription oldDescription) ;

    /**
     * saves the new argument: ID is modified and argument becomes immutable.
     * @param newProfile
     */
    public void saveConfigProfile(AConfigProfile newProfile) ;
    // marks the Ghost's end date

    /**
     * saves argument
     * @param deprecatedProfile
     */
    public void savePastProfile(PastConfigProfile deprecatedProfile) ;

    /**
     * get configProfile with name and tag
     * @param name
     * @param tag
     * @return null if not found
     */
    public AConfigProfile getActiveConfigProfile(String name, String tag) ;

    /**
     * delectes the active profile from DB
     * @param oldProfile
     */
    public void deleteActiveConfigProfile(AConfigProfile oldProfile) ;

    /**
     * registers a modified  parameter
     * @param config
     */
    public void modifyParmConfig(AParameterConfiguration config) ;

    /**
     * gets the active configProfiles that references an active SubsystemDescription
     * @param description
     * @return
     */
    public Collection<AConfigProfile> getActiveProfilesForSubsystem(ASubsystemDescription description) ;

    /**
     * get the deprecated ConfigProfile that referenced a subsystemDescription (active or deprecated)
     * @param description
     * @return
     */
    public Collection<PastConfigProfile> getProfilesForSubsystem(GhostSubsystemDescription description) ;

    /**
     * saves a run history
     * @param runHistory
     */
    public void saveRun(RunHistory runHistory) ;

    /**
     * saves a preparedConfiguration
     * @param preparedConfiguration
     */
    public void savePreparedConfiguration(PreparedConfiguration preparedConfiguration) ;

    /**
     * returns a prepared Configuration
     * @param subsystemName
     * @param configName
     * @param tag
     * @return null if not found
     */
    public PreparedConfiguration getPreparedConfiguration(String subsystemName, String configName, String tag) ;

    /**
     * saves a machine configuration
     * @param machineConfiguration
     */
    public void saveMachineConfiguration(MachineConfiguration machineConfiguration) ;

    /**
     * get a machine configuration..
     * @param macAddress
     * @return null if not found
     */
    public MachineConfiguration getMachineConfiguration(String macAddress) ;

    /**
     * execut simple request (read only: select of From)
     * @param hqlString
     * @return
     */
    public List<?> simpleHQLRequest(String hqlString) ;

    /**
     * claose all
     */
    public void close() ;
}
